@@ -60,6 +60,7 @@ from .loggers.pytorch_logger import patch as pytorch_patch
 from .loggers.sklearn_logger import patch as sklearn_patch
 from .loggers.tensorboard_logger import patch as tb_patch
 from .loggers.tensorflow_logger import patch as tf_patch
+from .loggers.tfma_logger import patch as tfma_patch
 from .loggers.xgboost_logger import patch as xg_patch
 from .logging_messages import ONLINE_EXPERIMENT_THROTTLED
 from .monkey_patching import CometModuleFinder
@@ -95,6 +96,7 @@ if not get_config("comet.disable_auto_logging"):
     fastai_patch(MODULE_FINDER)
     mlflow_patch(MODULE_FINDER)
     xg_patch(MODULE_FINDER)
+    tfma_patch(MODULE_FINDER)
     MODULE_FINDER.start()
 
 # Configure the logging
