@@ -12,8 +12,9 @@
 #  the express permission of Comet ML Inc.
 # *******************************************************
 
-import keras
+import logging
 
+from ..logging_messages import TF_KERAS_FALLBACK_FAILED
 from ._base import (
     build_base_callback,
     build_empty_keras_callback,
@@ -21,7 +22,22 @@ from ._base import (
     build_predictive_early_stopping_keras_callback,
 )
 
-BaseCallback = build_base_callback(keras.callbacks.Callback)
+LOGGER = logging.getLogger(__name__)
+
+try:
+    import keras
+except ImportError as exc:
+    try:
+        import tensorflow.keras as keras
+    except ImportError:
+        LOGGER.warning(
+            TF_KERAS_FALLBACK_FAILED, exc_info=True,
+        )
+        raise exc
+
+baseclass = keras.callbacks.Callback
+
+BaseCallback = build_base_callback(baseclass)
 
 PredictiveEarlyStoppingKerasCallback = build_predictive_early_stopping_keras_callback(
     BaseCallback
