@@ -57,7 +57,12 @@ from .messages import (
     UploadFileMessage,
     UploadInMemoryMessage,
 )
-from .utils import data_to_fp, wait_for_empty, write_file_like_to_tmp_file
+from .utils import (
+    data_to_fp,
+    log_once_at_level,
+    wait_for_empty,
+    write_file_like_to_tmp_file,
+)
 
 DEBUG = False
 LOGGER = logging.getLogger(__name__)
@@ -455,7 +460,7 @@ class Streamer(BaseStreamer):
 
         msg = "Uploading stats to Comet before program termination (may take several seconds)"
         if not self._is_msg_queue_empty():
-            LOGGER.info(msg)
+            log_once_at_level(logging.INFO, msg)
 
             wait_for_empty(
                 self._is_msg_queue_empty,
@@ -700,14 +705,14 @@ class OfflineStreamer(BaseStreamer):
     def wait_for_finish(self):
         """ Blocks the experiment from exiting until all data was sent to server OR 30 seconds passed."""
 
-        msg = "Uploading stats to Comet before program termination (may take several seconds)"
-        LOGGER.info(msg)
+        msg = "Saving offline stats to disk before program termination (may take several seconds)"
+        log_once_at_level(logging.INFO, msg)
 
         # Wait maximum 2 minutes
         self._wait_for_empty(30)
 
         if not self.messages.empty():
-            msg = "Still uploading stats to Comet before program termination (may take several seconds)"
+            msg = "Still saving offline stats to disk before program termination (may take several seconds)"
             LOGGER.info(msg)
             self._wait_for_empty(30)
 
