@@ -461,7 +461,7 @@ try:
             if self.consumer_thread:
                 self.consumer_thread.join(5)
                 if self.consumer_thread.is_alive():
-                    LOGGER.warning("Consumer thread did not finished")
+                    LOGGER.warning("Consumer thread did not finish")
 
             os.close(self.stdout_control_out)
             os.close(self.stdout_control_in)
