@@ -17,9 +17,42 @@ import logging
 import wrapt
 
 from .._logging import check_module
+from .._typing import Any
+from ..experiment import BaseExperiment
 
 LOGGER = logging.getLogger(__name__)
-SCALE_LOSS_ORIGINAL = None
+
+
+def _get_loss(loss_backward, experiment):
+    # type: (Any, BaseExperiment) -> Any
+    """ Returns the right loss tensor based on the loss tensor object where
+    backward has been called. The right loss might be the unscaled one when
+    using APEX or Pytorch 1.6 AMP
+    """
+    experiment._localstorage.__dict__.setdefault("pytorch", {}).setdefault(
+        "amp_loss_mapping", {}
+    )
+    return experiment._localstorage.pytorch["amp_loss_mapping"].get(
+        id(loss_backward), loss_backward
+    )
+
+
+def _add_amp_loss_mapping(scaled_loss, unscaled_loss, experiment):
+    # type: (int, Any, BaseExperiment) -> None
+    # First argument is the scaled_loss id
+    experiment._localstorage.__dict__.setdefault("pytorch", {}).setdefault(
+        "amp_loss_mapping", {}
+    )
+    experiment._localstorage.pytorch["amp_loss_mapping"][scaled_loss] = unscaled_loss
+
+
+def _clean_amp_loss_mapping(scaled_loss, experiment):
+    # type: (int, BaseExperiment) -> None
+    # First argument is the scaled_loss id
+    experiment._localstorage.__dict__.setdefault("pytorch", {}).setdefault(
+        "amp_loss_mapping", {}
+    )
+    experiment._localstorage.pytorch["amp_loss_mapping"].pop(scaled_loss, None)
 
 
 def tensor_backward(experiment, original, result, *args, **kwargs):
@@ -34,12 +67,12 @@ def tensor_backward(experiment, original, result, *args, **kwargs):
             if experiment.curr_step == 0 and model is not None:
                 experiment._set_model_graph(model, framework="pytorch")
         if experiment.auto_metric_logging:
+            arg_loss = args[0]
+
             ## Throttle report to every 10 batch updates:
             if experiment.curr_step % 10 == 0:
-                if SCALE_LOSS_ORIGINAL is not None:
-                    loss = SCALE_LOSS_ORIGINAL
-                else:
-                    loss = args[0]
+                loss = _get_loss(arg_loss, experiment)
+
                 if len(loss.data.shape) == 0:
                     experiment._log_metric(
                         "loss",
@@ -54,6 +87,10 @@ def tensor_backward(experiment, original, result, *args, **kwargs):
                         step=experiment.curr_step,
                         framework="pytorch",
                     )
+
+            # Clean the reference to the original unscaled loss to avoid leaking
+            # memory
+            _clean_amp_loss_mapping(id(arg_loss), experiment)
     except Exception:
         LOGGER.info("Failed to run Tensor.backward logger", exc_info=True)
     return result
@@ -70,27 +107,42 @@ def model_constructor(experiment, original, *args, **kwargs):
 
 
 class CallableWrapper(wrapt.ObjectProxy):
-    def __init__(self, wrapped, original_loss):
+    def __init__(self, wrapped, original_loss, experiment):
         super(CallableWrapper, self).__init__(wrapped)
         self.original_loss = original_loss
+        self.experiment = experiment
+        self.scaled_loss = None
 
     def __enter__(self, *args, **kwargs):
         return_value = self.__wrapped__.__enter__(*args, **kwargs)
 
-        global SCALE_LOSS_ORIGINAL
-        SCALE_LOSS_ORIGINAL = self.original_loss
+        try:
+            self.scaled_loss = id(return_value)
+            _add_amp_loss_mapping(self.scaled_loss, self.original_loss, self.experiment)
+        except Exception:
+            LOGGER.debug("Error in Apex amp.scale_loss __enter__", exc_info=True)
 
         return return_value
 
     def __exit__(self, *args, **kwargs):
-        global SCALE_LOSS_ORIGINAL
-        SCALE_LOSS_ORIGINAL = None
+        try:
+            if self.scaled_loss:
+                _clean_amp_loss_mapping(self.scaled_loss, self.experiment)
+        except Exception:
+            LOGGER.debug("Error in Apex amp.scale_loss __exit__", exc_info=True)
 
         return self.__wrapped__.__exit__(*args, **kwargs)
 
 
 def scale_loss_hook(experiment, original, return_value, original_loss, *args, **kwargs):
-    return CallableWrapper(return_value, original_loss)
+    return CallableWrapper(return_value, original_loss, experiment)
+
+
+def amp_scale_loss_hook(
+    experiment, original, return_value, scaler, original_loss, *args, **kwargs
+):
+    # Save the original loss mapped to the scaled one so we can find it back after
+    _add_amp_loss_mapping(id(return_value), original_loss, experiment)
 
 
 def patch(module_finder):
@@ -106,5 +158,9 @@ def patch(module_finder):
 
     module_finder.register_after("apex.amp.handle", "scale_loss", scale_loss_hook)
 
+    module_finder.register_after(
+        "torch.cuda.amp.grad_scaler", "GradScaler.scale", amp_scale_loss_hook
+    )
+
 
 check_module("torch")
