@@ -8,8 +8,8 @@
 #
 #  Sign up for free at http://www.comet.ml
 #  Copyright (C) 2015-2020 Comet ML INC
-#  This file can not be copied and/or distributed without the express
-#  permission of Comet ML Inc.
+#  This file can not be copied and/or distributed without
+#  the express permission of Comet ML Inc.
 # *******************************************************
 
 
@@ -22,6 +22,7 @@ from ..utils import Histogram
 LOGGER = logging.getLogger(__name__)
 
 LOG_METRICS = True
+LOG_HISTOGRAMS = True
 
 
 def extract_from_add_summary(file_writer, summary, global_step):
@@ -61,18 +62,32 @@ def convert_histograms(histo):
 
 def add_summary_logger(experiment, original, value, *args, **kwargs):
     """
-    Note: auto_metric_logging controls summary metrics and histograms
+    Note: auto_metric_logging controls summary metrics, and
+        auto_metric_logging controls summary histograms
     Note: assumes "simple_value" is a metric
     """
     try:
-        if experiment.auto_metric_logging and not experiment.disabled_monkey_patching:
-            LOGGER.debug("TENSORBOARD LOGGER CALLED")
-            metrics, histograms, step = extract_from_add_summary(*args, **kwargs)
-            if metrics and LOG_METRICS:
+        LOGGER.debug("TENSORBOARD LOGGER CALLED")
+        metrics, histograms, step = extract_from_add_summary(*args, **kwargs)
+
+        if metrics and experiment.auto_metric_logging:
+            if LOG_METRICS:
                 experiment._log_metrics(metrics, step=step, framework="tensorboard")
-            if histograms:
+            else:
+                experiment._log_once_at_level(
+                    logging.INFO,
+                    "ignoring tensorflow summary log of metrics because of keras; set `comet_ml.loggers.tensorboard_logger.LOG_METRICS = True` to override",
+                )
+
+        if histograms and experiment.auto_weight_logging:
+            if LOG_HISTOGRAMS:
                 for histo in histograms:
                     experiment.log_histogram_3d(convert_histograms(histo), step=step)
+            else:
+                experiment._log_once_at_level(
+                    logging.INFO,
+                    "ignoring tensorflow summary log of histograms because of keras; set `comet_ml.loggers.tensorboard_logger.LOG_HISTOGRAMS = True` to override",
+                )
 
     except Exception:
         LOGGER.error(
@@ -85,13 +100,15 @@ def summary_scalar_logger(experiment, original, value, *args, **kwargs):
     Note: Assumes summary.scalars are metrics.
     """
     try:
-        if (
-            experiment.auto_metric_logging
-            and not experiment.disabled_monkey_patching
-            and LOG_METRICS
-        ):
-            name, data, step = get_args(*args, **kwargs)
-            experiment._log_metric(name, data, step=step, framework="tensorboard")
+        if experiment.auto_metric_logging:
+            if LOG_METRICS:
+                name, data, step = get_args(*args, **kwargs)
+                experiment._log_metric(name, data, step=step, framework="tensorboard")
+            else:
+                experiment._log_once_at_level(
+                    logging.INFO,
+                    "ignoring tensorflow summary log of metrics because of keras; set `comet_ml.loggers.tensorboard_logger.LOG_METRICS = True` to override",
+                )
     except Exception:
         LOGGER.error(
             "Failed to extract metrics from tensorflow.summary.scalar()", exc_info=True
@@ -103,9 +120,8 @@ def summary_text_logger(experiment, original, value, *args, **kwargs):
     Logs text from summary logger
     """
     try:
-        if not experiment.disabled_monkey_patching:
-            name, data, step = get_args(*args, **kwargs)
-            experiment.log_text(data, step=step, metadata={"name": name})
+        name, data, step = get_args(*args, **kwargs)
+        experiment.log_text(data, step=step, metadata={"name": name})
     except Exception:
         LOGGER.error("Failed to extract from tensorflow.summary.text()", exc_info=True)
 
@@ -115,11 +131,8 @@ def summary_audio_logger(experiment, original, value, *args, **kwargs):
     Logs audio from summary logger
     """
     try:
-        if not experiment.disabled_monkey_patching:
-            name, data, step, sample_rate = get_audio_args(*args, **kwargs)
-            experiment.log_audio(
-                data, file_name=name, sample_rate=sample_rate, step=step
-            )
+        name, data, step, sample_rate = get_audio_args(*args, **kwargs)
+        experiment.log_audio(data, file_name=name, sample_rate=sample_rate, step=step)
     except Exception:
         LOGGER.error("Failed to extract from tensorflow.summary.audio()", exc_info=True)
 
@@ -129,19 +142,25 @@ def summary_image_logger(experiment, original, value, *args, **kwargs):
     Logs an image from summary logger
     """
     try:
-        if not experiment.disabled_monkey_patching:
-            name, data, step = get_args(*args, **kwargs)
-            for image in data:
-                experiment.log_image(image, step=step)
+        name, data, step = get_args(*args, **kwargs)
+        for image in data:
+            experiment.log_image(image, step=step)
     except Exception:
         LOGGER.error("Failed to extract from tensorflow.summary.image()", exc_info=True)
 
 
 def summary_histogram_3d_logger(experiment, original, value, *args, **kwargs):
     try:
-        if experiment.auto_metric_logging and not experiment.disabled_monkey_patching:
-            name, data, step = get_args(*args, **kwargs)
-            experiment.log_histogram_3d(data, name, step=step)
+        if experiment.auto_weight_logging:
+            if LOG_HISTOGRAMS:
+                name, data, step = get_args(*args, **kwargs)
+                experiment.log_histogram_3d(data, name, step=step)
+            else:
+                experiment._log_once_at_level(
+                    logging.INFO,
+                    "ignoring tensorflow summary log of histograms because of keras; set `comet_ml.loggers.tensorboard_logger.LOG_HISTOGRAMS = True` to override",
+                )
+
     except Exception:
         LOGGER.error(
             "Failed to extract histogram 3D from tensorflow.summary.histogram()",
