@@ -98,6 +98,7 @@ class OfflineExperiment(BaseExperiment):
         log_env_cpu=True,  # type: Optional[bool]
         display_summary_level=None,  # type: Optional[int]
         auto_weight_logging=False,  # type: Optional[bool]
+        auto_log_co2=False,  # type: Optional[bool]
     ):
         # type: (...) -> None
         """
@@ -120,6 +121,8 @@ class OfflineExperiment(BaseExperiment):
                 `"default"` which will detect your environment and deactivate
                 the output logging for IPython and Jupyter environment and
                 sets `"native"` in the other cases.
+            auto_log_co2: Default(True) - automatically tracks the CO2 emission of
+                this experiment if `codecarbon` package is installed in the environment
             parse_args: Default(True) - allows you to enable/disable automatic parsing of CLI arguments
             log_env_details: Default(True) - log various environment
                 information in order to identify where the script is running
@@ -180,6 +183,7 @@ class OfflineExperiment(BaseExperiment):
             display_summary_level=display_summary_level,
             log_env_cpu=log_env_cpu,
             auto_weight_logging=auto_weight_logging,
+            auto_log_co2=auto_log_co2,
         )
 
         if not self.disabled:
@@ -194,12 +198,14 @@ class OfflineExperiment(BaseExperiment):
 
         if self.disabled is not True:
             if api_key is not None:
-                LOGGER.warning(
-                    "api_key was given, but is ignored in OfflineExperiment(); remember to set when you upload"
+                self._log_once_at_level(
+                    logging.WARNING,
+                    "api_key was given, but is ignored in OfflineExperiment(); remember to set when you upload",
                 )
             elif self.api_key is not None:
-                LOGGER.info(
-                    "COMET_API_KEY was set, but is ignored in OfflineExperiment(); remember to set when you upload"
+                self._log_once_at_level(
+                    logging.INFO,
+                    "COMET_API_KEY was set, but is ignored in OfflineExperiment(); remember to set when you upload",
                 )
 
             self._start()
