@@ -455,15 +455,15 @@ class Optimizer(object):
         Fill in defaults for predictor, if given.
         """
         if predictor_spec is not None:
+            # Keep in sync with Predictor.__init__ default values
             defaults = {
-                "loss_name": "val_loss",
-                "patience": 4,
-                "threshold": 0.1,
-                "api": None,
-                "optimizer_id": None,
-                "interval": 5,
-                "start": 5,
+                "loss_name": "loss",
                 "mode": "global",
+                "n_init_experiments": 0,
+                "patience": 10,
+                "start_step": 10,
+                "threshold": 0.1,
+                "time_interval": 300,
             }
             defaults.update(predictor_spec)
             return defaults
@@ -622,24 +622,24 @@ class Optimizer(object):
 
         if self.predictor_spec:
             LOGGER.debug("Setting predictor in experiment: %s", self.predictor_spec)
+
             if isinstance(exp, OfflineExperiment):
                 mode = "local"
             else:
+                # This should be at least global as it is set in Optimizer._fill_defaults_predictor
                 mode = self.predictor_spec["mode"]
 
+            # Old version of the Python SDK used to store predictor_spec with an
+            # empty optimizer_id, which would leads to TypeError: type object
+            # got multiple values for keyword argument 'optimizer_id'
+            # Also pop mode as it is passed explicitely
+            predictor_spec = self.predictor_spec.copy()
+            predictor_spec.pop("optimizer_id", None)
+            predictor_spec.pop("mode", None)
+
             try:
                 exp.set_predictor(
-                    Predictor(
-                        exp,
-                        loss_name=self.predictor_spec["loss_name"],
-                        patience=self.predictor_spec["patience"],
-                        threshold=self.predictor_spec["threshold"],
-                        api=self.predictor_spec["api"],
-                        optimizer_id=self.id,
-                        interval=self.predictor_spec["interval"],
-                        start=self.predictor_spec["start"],
-                        mode=mode,
-                    )
+                    Predictor(exp, optimizer_id=self.id, mode=mode, **predictor_spec)
                 )
             except Exception:
                 LOGGER.warning(
