@@ -1512,13 +1512,32 @@ def fast_flatten(items):
         return flatten(items)
 
 
+def convert_dict_to_string(user_data):
+    # type: (Dict) -> str
+    try:
+        return json.dumps(user_data, sort_keys=True)
+    except TypeError:
+        retval = {}
+        for key in user_data:
+            try:
+                value = convert_to_string(user_data[key])
+            except Exception:
+                value = str(user_data[key])
+            retval[key] = value
+        return str(retval)
+
+
 def convert_to_string(user_data):
     # type: (Any) -> str
     """
     Given an object, return it as a string.
     """
     if isinstance(user_data, Mapping):
-        user_data = json.dumps(user_data, sort_keys=True)
+        return convert_dict_to_string(user_data)
+
+    # hydra ConfigNode special case:
+    if hasattr(user_data, "node"):
+        return convert_dict_to_string(user_data.node)
 
     if hasattr(user_data, "numpy"):
         user_data = convert_tensor_to_numpy(user_data)
@@ -1684,6 +1703,10 @@ def convert_object_to_dictionary(obj):
     computed properties) into a {property_name: string, ...}
     dictionary.
     """
+    # hydra ConfigStore special case:
+    if obj.__class__.__module__.startswith("hydra.core") and hasattr(obj, "repo"):
+        return obj.repo
+
     dic = {}
     for attr in dir(obj):
         if attr.startswith("__") or attr.startswith("to_"):
